import wx

if wx.VERSION < (2, 8, 9, 0):
    raise Exception("This demo requires wxPython version greater than 2.8.9.0")

import AquaButton as AB

# Simple log class...
class MyLog(wx.PyLog):
    def __init__(self, textCtrl, logTime=0):
        wx.PyLog.__init__(self)
        self.tc = textCtrl
        self.logTime = logTime

    def DoLogString(self, message, timeStamp):
        if self.tc:
            self.tc.AppendText(message + '\n')

            
class AquaButtonDemo(wx.Frame):

    def __init__(self, parent, id=wx.ID_ANY, title="", pos=wx.DefaultPosition,
                 size=wx.DefaultSize, style=wx.DEFAULT_FRAME_STYLE):

        wx.Frame.__init__(self, parent, id, title, pos, size, style)

        self.mainPanel = wx.Panel(self)
        
        # Initialize AquaButton 1 (with image)
        bitmap = wx.Bitmap("button.png", wx.BITMAP_TYPE_PNG)
        self.btn1 = AB.AquaButton(self.mainPanel, -1, bitmap, "AquaButton")
        # Initialize AquaButton 2 (no image)
        self.btn2 = AB.AquaButton(self.mainPanel, -1, None, "Hello World!")

        self.backColour = wx.ColourPickerCtrl(self.mainPanel, col=self.btn2.GetBackgroundColour())
        self.hoverColour = wx.ColourPickerCtrl(self.mainPanel, col=self.btn2.GetHoverColour())
        self.textColour = wx.ColourPickerCtrl(self.mainPanel, col=self.btn2.GetForegroundColour())
        self.pulseCheck = wx.CheckBox(self.mainPanel, -1, "Pulse On Focus")

        # Set up a log window
        self.log = wx.TextCtrl(self.mainPanel, -1,
                               style = wx.TE_MULTILINE|wx.TE_READONLY|wx.HSCROLL)
        if wx.Platform == "__WXMAC__":
            self.log.MacCheckSpelling(False)
            
        # But instead of the above we want to show how to use our own wx.Log class
        wx.Log_SetActiveTarget(MyLog(self.log))
        
        self.CreateMenuBar()

        self.SetProperties()
        self.DoLayout()
        self.BindEvents()
        
        self.CenterOnScreen()
        self.Show()
        

    def CreateMenuBar(self):

        menuBar = wx.MenuBar(wx.MB_DOCKABLE)
        fileMenu = wx.Menu()
        helpMenu = wx.Menu()
        
        item = wx.MenuItem(fileMenu, wx.ID_ANY, "E&xit", "Exit demo")
        self.Bind(wx.EVT_MENU, self.OnClose, item)
        fileMenu.AppendItem(item)

        item = wx.MenuItem(helpMenu, wx.ID_ANY, "About...", "Shows The About Dialog")
        self.Bind(wx.EVT_MENU, self.OnAbout, item)
        helpMenu.AppendItem(item)
        
        menuBar.Append(fileMenu, "&File")
        menuBar.Append(helpMenu, "&Help")

        self.SetMenuBar(menuBar)


    def SetProperties(self):        

        self.SetTitle("AquaButton wxPython Demo ;-)")
        self.SetIcon(wx.Icon("wxpdemo.ico", wx.BITMAP_TYPE_ICO))
        self.log.write("Log Window\n\n")


    def DoLayout(self):

        frameSizer = wx.BoxSizer(wx.VERTICAL)
        mainSizer = wx.BoxSizer(wx.VERTICAL)
        
        btnSizer = wx.FlexGridSizer(2, 2, 15, 15)

        colourSizer = wx.FlexGridSizer(2, 3, 1, 10)

        btnSizer.Add(self.btn1, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL)
        btnSizer.Add(self.pulseCheck, 0, wx.ALIGN_CENTER_VERTICAL)
        
        btnSizer.Add(self.btn2, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL)
        
        labelBack = wx.StaticText(self.mainPanel, -1, "Background Colour")
        labelHover = wx.StaticText(self.mainPanel, -1, "Hover Colour")
        labelText = wx.StaticText(self.mainPanel, -1, "Text Colour")

        colourSizer.Add(labelBack)
        colourSizer.Add(labelHover)
        colourSizer.Add(labelText)

        colourSizer.Add(self.backColour, 0, wx.EXPAND)
        colourSizer.Add(self.hoverColour, 0, wx.EXPAND)
        colourSizer.Add(self.textColour, 0, wx.EXPAND)

        btnSizer.Add(colourSizer, 0, wx.EXPAND|wx.ALIGN_CENTER_VERTICAL)
        label1 = wx.StaticText(self.mainPanel, -1, "Welcome to the AquaButton demo for wxPython!")
        
        mainSizer.Add(label1, 0, wx.EXPAND|wx.LEFT|wx.RIGHT|wx.TOP, 10)
        mainSizer.Add(btnSizer, 1, wx.EXPAND|wx.ALL, 30)

        boldFont = wx.SystemSettings_GetFont(wx.SYS_DEFAULT_GUI_FONT)
        boldFont.SetWeight(wx.BOLD)
        
        for child in self.mainPanel.GetChildren():
            if isinstance(child, wx.StaticText):
                child.SetFont(boldFont)

        mainSizer.Add(self.log, 1, wx.EXPAND|wx.ALL, 5)
        
        self.mainPanel.SetSizer(mainSizer)
        mainSizer.Layout()
        frameSizer.Add(self.mainPanel, 1, wx.EXPAND)
        self.SetSizer(frameSizer)
        frameSizer.Layout()
        self.Fit()
        frameSizer.SetSizeHints(self)


    def BindEvents(self):

        self.Bind(wx.EVT_CLOSE, self.OnClose)
        self.Bind(wx.EVT_CHECKBOX, self.OnPulse, self.pulseCheck)
        self.Bind(wx.EVT_COLOURPICKER_CHANGED, self.OnPickColour)
        self.Bind(wx.EVT_BUTTON, self.OnButton, self.btn1)
        self.Bind(wx.EVT_BUTTON, self.OnButton, self.btn2)


    def OnPulse(self, event):

        self.btn1.SetPulseOnFocus(event.IsChecked())


    def OnPickColour(self, event):

        obj = event.GetEventObject()
        colour = event.GetColour()
        if obj == self.backColour:
            self.btn2.SetBackgroundColour(colour)
        elif obj == self.hoverColour:
            self.btn2.SetHoverColour(colour)
        else:
            self.btn2.SetForegroundColour(colour)

            
    def OnClose(self, event):

        wx.CallAfter(self.Destroy)


    def OnButton(self, event):

        obj = event.GetEventObject()
        self.log.write("You clicked %s\n"%obj.GetLabel())


    def OnAbout(self, event):

        msg = "This is the about dialog of AquaButton demo.\n\n" + \
              "Author: Andrea Gavana @ 07 Oct 2008\n\n" + \
              "Please report any bugs/requests of improvements\n" + \
              "to me at the following addresses:\n\n" + \
              "andrea.gavana@gmail.com\n" + "gavana@kpo.kz\n\n" + \
              "Welcome to wxPython " + wx.VERSION_STRING + "!!"
              
        dlg = wx.MessageDialog(self, msg, "AquaButton wxPython Demo",
                               wx.OK | wx.ICON_INFORMATION)
        dlg.ShowModal()
        dlg.Destroy()        

        
app = wx.PySimpleApp()
frame = AquaButtonDemo(None, size=(700, 500))
app.MainLoop()

